@@ -4,15 +4,14 @@ class ConfigurationException(Exception):
 
 # Request related exceptions
 class BaseRequestException(Exception):
-    def __init__(self, response, message=None, error=None):
+    def __init__(self, response, message=None, error=None, error_description=None):
         super(BaseRequestException, self).__init__(message)
 
+        self.message = message
         self.error = error
+        self.error_description = error_description
         self.extract_and_set_response_related_data(response)
 
-        if message is not None:
-            self.message = message
-
     def extract_and_set_response_related_data(self, response):
         self.response = response
 
@@ -35,6 +34,9 @@ class BaseRequestException(Exception):
         if self.error is not None:
             exception += ", error=%s" % self.error
 
+        if self.error_description is not None:
+            exception += ", error_description=%s" % self.error_description
+
         return exception + ")"
 
 
