@@ -8,6 +8,7 @@ from workos.utils.request import (
     REQUEST_METHOD_PUT,
 )
 from workos.utils.validation import ORGANIZATIONS_MODULE, validate_settings
+from workos.resources.organizations import WorkOSOrganization
 
 ORGANIZATIONS_PATH = "organizations"
 RESPONSE_LIMIT = 10
@@ -69,12 +70,14 @@ class Organizations(object):
         Returns:
             dict: Organization response from WorkOS
         """
-        return self.request_helper.request(
+        response = self.request_helper.request(
             "organizations/{organization}".format(organization=organization),
             method=REQUEST_METHOD_GET,
             token=workos.api_key,
         )
 
+        return WorkOSOrganization.construct_from_response(response).to_dict()
+
     def create_organization(self, organization):
         """Create an organization
 
@@ -89,38 +92,45 @@ class Organizations(object):
         Returns:
             dict: Created Organization response from WorkOS.
         """
-        return self.request_helper.request(
+        response = self.request_helper.request(
             ORGANIZATIONS_PATH,
             method=REQUEST_METHOD_POST,
             params=organization,
             token=workos.api_key,
         )
 
-    def update_organization(self, organization, name, domains=None):
+        return WorkOSOrganization.construct_from_response(response).to_dict()
+
+    def update_organization(
+        self, organization, name, allow_profiles_outside_organization=None, domains=None
+    ):
         """Update an organization
 
         Args:
             organization(str) - Organization's unique identifier.
             name (str) - A unique, descriptive name for the organization.
-            organization[allow_profiles_outside_organization] (boolean) - Whether Connections
-                    within the Organization allow profiles that are outside of the Organization's
-                    configured User Email Domains. (Optional)
+            allow_profiles_outside_organization (boolean) - Whether Connections
+                within the Organization allow profiles that are outside of the Organization's
+                configured User Email Domains. (Optional)
             domains (list) - List of domains that belong to the organization. (Optional)
 
         Returns:
             dict: Updated Organization response from WorkOS.
         """
         params = {
-            "domains": domains,
             "name": name,
+            "domains": domains,
+            "allow_profiles_outside_organization": allow_profiles_outside_organization,
         }
-        return self.request_helper.request(
+        response = self.request_helper.request(
             "organizations/{organization}".format(organization=organization),
             method=REQUEST_METHOD_PUT,
             params=params,
             token=workos.api_key,
         )
 
+        return WorkOSOrganization.construct_from_response(response).to_dict()
+
     def delete_organization(self, organization):
         """Deletes a single Organization
 
